==> haskell-commonmark-pandoc-0.2.2.3-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-pandoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-pandoc
version:              0.2.2.3
visibility:           public
id:                   commonmark-pandoc-0.2.2.3-3Rina6po1iiFArtEaNi41B
key:                  commonmark-pandoc-0.2.2.3-3Rina6po1iiFArtEaNi41B
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Bridge between commonmark and pandoc AST.
description:
    This library provides typeclasses for rendering
    commonmark to Pandoc types.

category:             Text
abi:                  ce1b67858a03c20c3aac25ede595ebce
exposed:              True
exposed-modules:      Commonmark.Pandoc
import-dirs:          /usr/lib/ghc-9.4.8/site-local/commonmark-pandoc-0.2.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/commonmark-pandoc-0.2.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/commonmark-pandoc-0.2.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-pandoc
hs-libraries:         HScommonmark-pandoc-0.2.2.3-3Rina6po1iiFArtEaNi41B
depends:
    base-4.17.2.1 commonmark-0.2.6-vzpQmHkDiqnPJoe9xP0b
    commonmark-extensions-0.2.5.5-7sX8AsJduk1J0Bz8VUqB48
    pandoc-types-1.23.1-ECK1zuYhKfx6GZrEU3gYj1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-pandoc/html/commonmark-pandoc.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-pandoc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-pandoc-0.2.2.3-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-pandoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-pandoc
version:              0.2.2.3
visibility:           public
id:                   commonmark-pandoc-0.2.2.3-FRGA3A4xyrWJWRgPciPDJp
key:                  commonmark-pandoc-0.2.2.3-FRGA3A4xyrWJWRgPciPDJp
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Bridge between commonmark and pandoc AST.
description:
    This library provides typeclasses for rendering
    commonmark to Pandoc types.

category:             Text
abi:                  6f695fcfb46ae528d72ac28c5b93b674
exposed:              True
exposed-modules:      Commonmark.Pandoc
import-dirs:          /usr/lib/ghc-9.4.8/site-local/commonmark-pandoc-0.2.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/commonmark-pandoc-0.2.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/commonmark-pandoc-0.2.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-pandoc
hs-libraries:         HScommonmark-pandoc-0.2.2.3-FRGA3A4xyrWJWRgPciPDJp
depends:
    base-4.17.2.1 commonmark-0.2.6-GF8oaxHu1yIJs8o2pZcx
    commonmark-extensions-0.2.5.5-71xej1gDsH05pVchRtapQA
    pandoc-types-1.23.1-CLDITckbd5IHUKBBSAuTOr text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-pandoc/html/commonmark-pandoc.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-pandoc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
